:mod:`oujago.nlp.hanziconverter`
================================

.. automodule:: oujago.nlp.hanziconverter

.. autosummary::

    HanziConverter


Detailed Description
--------------------


.. autoclass:: HanziConverter
    :members:








